@@ -19,7 +19,4 @@
 #
 # Author: David Zeuthen <davidz@redhat.com>
 
-DATADIR = "${prefix}/share"
-DATADIR = DATADIR.replace(
-    "${prefix}", "/home/mclasen/gnome")
-VERSION = "2.53.3"
+VERSION = "2.53.4"
