@@ -5,23 +5,25 @@
 #include <gio/gio.h>
 #include <gstdio.h>
 
-const gchar *datapath;
-const gchar *glib_compile_schemas;
-
 typedef struct {
   const gchar *name;
   const gchar *opt;
   const gchar *err;
 } SchemaTest;
 
+/* Meson build defines this, autotools build does not */
+#ifndef GLIB_COMPILE_SCHEMAS
+#define GLIB_COMPILE_SCHEMAS "../glib-compile-schemas"
+#endif
+
 static void
 test_schema_do_compile (gpointer data)
 {
   SchemaTest *test = (SchemaTest *) data;
   gchar *filename = g_strconcat (test->name, ".gschema.xml", NULL);
-  gchar *path = g_build_filename (datapath, "schema-tests", filename, NULL);
+  gchar *path = g_test_build_filename (G_TEST_DIST, "schema-tests", filename, NULL);
   gchar *argv[] = {
-    (gchar*)glib_compile_schemas,
+    GLIB_COMPILE_SCHEMAS,
     "--strict",
     "--dry-run",
     "--schema-file", path,
@@ -47,6 +49,8 @@ test_schema (gpointer data)
   if (test->err)
     {
       g_test_trap_assert_failed ();
+      g_test_trap_assert_stderr_unmatched ("*CRITICAL*");
+      g_test_trap_assert_stderr_unmatched ("*WARNING*");
       g_test_trap_assert_stderr (test->err);
     }
   else
@@ -108,14 +112,14 @@ static const SchemaTest tests[] = {
   { "range-parse-error",            NULL, "*invalid character in number*"                       },
   { "from-docs",                    NULL, NULL                                                  },
   { "extending",                    NULL, NULL                                                  },
-  { "extend-missing",               NULL, "*extends not-yet-existing schema*"                   },
+  { "extend-missing",               NULL, "*extends not yet existing schema*"                   },
   { "extend-nonlist",               NULL, "*which is not a list*"                               },
-  { "extend-self",                  NULL, "*not-yet-existing*"                                  },
+  { "extend-self",                  NULL, "*not yet existing*"                                  },
   { "extend-wrong-list-indirect",   NULL, "*'y' does not extend 'x'*"                           },
   { "extend-wrong-list",            NULL, "*'y' does not extend 'x'*"                           },
   { "key-in-list-indirect",         NULL, "*cannot add keys to a 'list*"                        },
   { "key-in-list",                  NULL, "*cannot add keys to a 'list*"                        },
-  { "list-of-missing",              NULL, "*is list of not-yet-existing schema*"                },
+  { "list-of-missing",              NULL, "*is list of not yet existing schema*"                },
   { "extend-and-shadow",            NULL, "*shadows*use <override>*"                            },
   { "extend-and-shadow-indirect",   NULL, "*shadows*use <override>*"                            },
   { "override",                     NULL, NULL                                                  },
@@ -129,6 +133,9 @@ static const SchemaTest tests[] = {
   { "flags-more-than-one-bit",      NULL, "*flags values must have at most 1 bit set*"          },
   { "flags-with-enum-attr",         NULL, "*<enum id='flags'> not (yet) defined*"               },
   { "flags-with-enum-tag",          NULL, "*<flags id='flags'> not (yet) defined*"              },
+  { "summary-xmllang",              NULL, "*Only one <summary> element allowed*"                },
+  { "description-xmllang",          NULL, "*Only one <description> element allowed*"            },
+  { "summary-xmllang-and-attrs",    NULL, "*attribute 'lang' invalid for element 'summary'*"    },
   { "inherit-gettext-domain",       NULL, NULL                                                  },
   { "range-type-test",              NULL, NULL                                                  },
   { "cdata",                        NULL, NULL                                                  }
@@ -142,16 +149,6 @@ main (int argc, char *argv[])
 
   setlocale (LC_ALL, "");
 
-  if (g_getenv ("G_TEST_DATA"))
-    datapath = g_getenv ("G_TEST_DATA");
-  else
-    datapath = SRCDIR;
-
-  if (g_getenv ("GLIB_COMPILE_SCHEMAS"))
-    glib_compile_schemas = g_getenv ("GLIB_COMPILE_SCHEMAS");
-  else
-    glib_compile_schemas = "/usr/bin/glib-compile-schemas";
-
   g_test_init (&argc, &argv, NULL);
 
   for (i = 0; i < G_N_ELEMENTS (tests); ++i)
